# Publications
(Publications)=

### [Extending Quantum Computing through Subspace, Embedding and Classical Molecular Dynamics Techniques](https://arxiv.org/abs/2505.16796)

The advent of hybrid computing platforms consisting of quantum processing units integrated with conventional high-performance computing brings new opportunities for algorithms design. By strategically offloading select portions of the workload to classical hardware where tractable, we may broaden the applicability of quantum computation in the near term. In this perspective, we review techniques that facilitate the study of subdomains of chemical systems with quantum computers and present a proof-of-concept demonstration of quantum-selected configuration interaction deployed within a multiscale/multiphysics simulation workflow leveraging classical molecular dynamics, projection-based embedding and qubit subspace tools. This allows the technology to be utilised for simulating systems of real scientific and industrial interest, which not only brings true quantum utility closer to realisation but is also relevant as we look forward to the fault-tolerant regime.

### [Scalable approach to quantum simulation via projection-based embedding](https://journals.aps.org/pra/abstract/10.1103/PhysRevA.109.022418)

Owing to the computational complexity of electronic structure algorithms running on classical digital computers, the range of molecular systems amenable to simulation remains tightly circumscribed even after many decades of work. Many believe quantum computers will transcend such limitations although in the current era the size and noise of these devices militates against significant progress. Here we describe a chemically intuitive approach that permits a subdomain of a molecule's electronic structure to be calculated accurately on a quantum device, while the rest of the molecule is described at a lower level of accuracy using density functional theory running on a classical computer. We demonstrate that this approach produces improved results for molecules that cannot be simulated fully on current quantum computers but which can be resolved classically at a cheaper level of approximation. The algorithm is tunable, so that the size of the quantum simulation can be adjusted to run on available quantum resources. Therefore, as quantum devices become larger, this method will enable increasingly large subdomains to be studied accurately.
